@@ -1,4 +1,4 @@
-print("running")
+print("changed")
 
 from .pandas_printer import format_pandas
 from pyperclip import copy
